;; Generated package description from srht.el  -*- no-byte-compile: t -*-
(define-package "srht" "0.3.0.20231110.195341" "Sourcehut" '((emacs "27.1") (plz "0.7")) :commit "54cb0366356d1bfe6ae208634012f70c14d39025" :authors '(("Aleksandr Vityazev" . "avityazev@posteo.org")) :maintainer '("Aleksandr Vityazev" . "avityazev@posteo.org") :keywords '("comm" "vc") :url "https://sr.ht/~akagi/srht.el/")
